Speed of gravity and LIV constraints from GW-GRB association paper template
-----
This manuscript is a template of generic papers to be sent to arxiv and/or AAS Research notes whenever a confirmed (to what level?) association between GW and GRB improves the constraints on the fractional difference between the speed of GW and photons.

Whenever a new interesting coincidence occurs, simply launch the code (SoG_manuscript_generator) with the address of the VOEvent of interrest (e.g. https://gracedb.ligo.org/apiweb/superevents/S190426c/files/S190426c-2-Initial.xml,0). 
The code generates a macro file (named "macro_GW_GRB.tex") with all the information relevant to a specific event, and then build a pdf from the latex file that has the generated macro as an input.

Auto-built PDF (in order to check the *.tex part of the manuscript only -> should later be modified to run the code SoG_manuscript_directly)
-----
PDFs are automatically generated when the content changes. The following link is updated automatically.
 * [Latest (APS style) PDF](https://git.ligo.org/olivier.minazzoli/sog_liv_manuscript_template/-/jobs/artifacts/master/file/SoG_LIV_arxiv_aps.pdf?job=pdf)
